@@ -2,7 +2,7 @@ package Web::Components;
 
 use 5.010001;
 use strictures;
-use version; our $VERSION = qv( sprintf '0.4.%d', q$Rev: 1 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.5.%d', q$Rev: 1 $ =~ /\d+/gmx );
 
 1;
 
@@ -12,6 +12,14 @@ __END__
 
 =encoding utf-8
 
+=begin html
+
+<a href="https://travis-ci.org/pjfl/p5-web-components"><img src="https://travis-ci.org/pjfl/p5-web-components.svg?branch=master" alt="Travis CI Badge"></a>
+<a href="http://badge.fury.io/pl/Web-Components"><img src="https://badge.fury.io/pl/Web-Components.svg" alt="CPAN Badge"></a>
+<a href="http://cpants.cpanauthors.org/dist/Web-Components"><img src="http://cpants.cpanauthors.org/dist/Web-Components.png" alt="Kwalitee Badge"></a>
+
+=end html
+
 =head1 Name
 
 Web::Components - MVC pattern for Web::Simple
